==> cxf-services-xkms-common-3.3.12-sources.jar: org/apache/cxf/xkms/model/xkms/ResultMinorEnum.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * &lt;p&gt;Java class for ResultMinorEnum.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * &lt;pre&gt;
 * &amp;lt;simpleType name="ResultMinorEnum"&amp;gt;
 *   &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyURI"&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#NoMatch"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#TooManyResponses"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#Incomplete"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#Failure"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#Refused"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#NoAuthentication"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#MessageNotSupported"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#UnknownResponseId"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#RepresentRequired"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#NotSynchronous"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#OptionalElementNotSupported"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#ProofOfPossessionRequired"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#TimeInstantNotSupported"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#TimeInstantOutOfRange"/&amp;gt;
 *   &amp;lt;/restriction&amp;gt;
 * &amp;lt;/simpleType&amp;gt;
 * &lt;/pre&gt;
 * 
 */
@XmlType(name = "ResultMinorEnum")
@XmlEnum
public enum ResultMinorEnum {

    @XmlEnumValue("http://www.w3.org/2002/03/xkms#NoMatch")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_NO_MATCH("http://www.w3.org/2002/03/xkms#NoMatch"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#TooManyResponses")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_TOO_MANY_RESPONSES("http://www.w3.org/2002/03/xkms#TooManyResponses"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Incomplete")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_INCOMPLETE("http://www.w3.org/2002/03/xkms#Incomplete"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Failure")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_FAILURE("http://www.w3.org/2002/03/xkms#Failure"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Refused")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_REFUSED("http://www.w3.org/2002/03/xkms#Refused"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#NoAuthentication")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_NO_AUTHENTICATION("http://www.w3.org/2002/03/xkms#NoAuthentication"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#MessageNotSupported")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_MESSAGE_NOT_SUPPORTED("http://www.w3.org/2002/03/xkms#MessageNotSupported"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#UnknownResponseId")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_UNKNOWN_RESPONSE_ID("http://www.w3.org/2002/03/xkms#UnknownResponseId"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#RepresentRequired")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_REPRESENT_REQUIRED("http://www.w3.org/2002/03/xkms#RepresentRequired"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#NotSynchronous")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_NOT_SYNCHRONOUS("http://www.w3.org/2002/03/xkms#NotSynchronous"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#OptionalElementNotSupported")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_OPTIONAL_ELEMENT_NOT_SUPPORTED("http://www.w3.org/2002/03/xkms#OptionalElementNotSupported"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#ProofOfPossessionRequired")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_PROOF_OF_POSSESSION_REQUIRED("http://www.w3.org/2002/03/xkms#ProofOfPossessionRequired"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#TimeInstantNotSupported")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_TIME_INSTANT_NOT_SUPPORTED("http://www.w3.org/2002/03/xkms#TimeInstantNotSupported"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#TimeInstantOutOfRange")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_TIME_INSTANT_OUT_OF_RANGE("http://www.w3.org/2002/03/xkms#TimeInstantOutOfRange");
    private final String value;

    ResultMinorEnum(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static ResultMinorEnum fromValue(String v) {
        for (ResultMinorEnum c: ResultMinorEnum.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> cxf-services-xkms-common-3.5.1-sources.jar: org/apache/cxf/xkms/model/xkms/ResultMinorEnum.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ResultMinorEnum.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <pre>
 * &lt;simpleType name="ResultMinorEnum"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyURI"&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#NoMatch"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#TooManyResponses"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Incomplete"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Failure"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Refused"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#NoAuthentication"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#MessageNotSupported"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#UnknownResponseId"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#RepresentRequired"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#NotSynchronous"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#OptionalElementNotSupported"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#ProofOfPossessionRequired"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#TimeInstantNotSupported"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#TimeInstantOutOfRange"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "ResultMinorEnum")
@XmlEnum
public enum ResultMinorEnum {

    @XmlEnumValue("http://www.w3.org/2002/03/xkms#NoMatch")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_NO_MATCH("http://www.w3.org/2002/03/xkms#NoMatch"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#TooManyResponses")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_TOO_MANY_RESPONSES("http://www.w3.org/2002/03/xkms#TooManyResponses"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Incomplete")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_INCOMPLETE("http://www.w3.org/2002/03/xkms#Incomplete"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Failure")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_FAILURE("http://www.w3.org/2002/03/xkms#Failure"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Refused")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_REFUSED("http://www.w3.org/2002/03/xkms#Refused"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#NoAuthentication")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_NO_AUTHENTICATION("http://www.w3.org/2002/03/xkms#NoAuthentication"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#MessageNotSupported")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_MESSAGE_NOT_SUPPORTED("http://www.w3.org/2002/03/xkms#MessageNotSupported"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#UnknownResponseId")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_UNKNOWN_RESPONSE_ID("http://www.w3.org/2002/03/xkms#UnknownResponseId"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#RepresentRequired")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_REPRESENT_REQUIRED("http://www.w3.org/2002/03/xkms#RepresentRequired"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#NotSynchronous")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_NOT_SYNCHRONOUS("http://www.w3.org/2002/03/xkms#NotSynchronous"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#OptionalElementNotSupported")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_OPTIONAL_ELEMENT_NOT_SUPPORTED("http://www.w3.org/2002/03/xkms#OptionalElementNotSupported"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#ProofOfPossessionRequired")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_PROOF_OF_POSSESSION_REQUIRED("http://www.w3.org/2002/03/xkms#ProofOfPossessionRequired"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#TimeInstantNotSupported")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_TIME_INSTANT_NOT_SUPPORTED("http://www.w3.org/2002/03/xkms#TimeInstantNotSupported"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#TimeInstantOutOfRange")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_TIME_INSTANT_OUT_OF_RANGE("http://www.w3.org/2002/03/xkms#TimeInstantOutOfRange");
    private final String value;

    ResultMinorEnum(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static ResultMinorEnum fromValue(String v) {
        for (ResultMinorEnum c: ResultMinorEnum.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
